@@ -1,26 +1,26 @@
 ############################################################
-# $Id: Data.pm,v 1.9 2005/12/29 18:16:59 nicolaw Exp $
-# Colloquy::Data - Read Colloquy 1.3 and 1.4 data files
-# Copyright: (c)2005 Nicola Worthington. All rights reserved.
-############################################################
-# This file is part of Colloquy::Data.
 #
-# Colloquy::Data is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+#   $Id: Data.pm,v 1.11 2006/01/07 12:13:27 nicolaw Exp $
+#   Colloquy::Data - Read Colloquy 1.3 and 1.4 data files
 #
-# Colloquy::Data is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+#   Copyright 2005,2006 Nicola Worthington
+#
+#   Licensed under the Apache License, Version 2.0 (the "License");
+#   you may not use this file except in compliance with the License.
+#   You may obtain a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#   Unless required by applicable law or agreed to in writing, software
+#   distributed under the License is distributed on an "AS IS" BASIS,
+#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#   See the License for the specific language governing permissions and
+#   limitations under the License.
 #
-# You should have received a copy of the GNU General Public License
-# along with Colloquy::Data; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 ############################################################
 
 package Colloquy::Data;
+# vim:ts=4:sw=4:tw=78
 
 use strict;
 use Exporter;
@@ -29,11 +29,11 @@ use Carp qw(cluck croak);
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use constant DEFAULT_DATADIR => '/usr/local/colloquy/data';
 
-$VERSION     = sprintf('%d.%02d', q$Revision: 1.9 $ =~ /(\d+)/g);
+$VERSION     = sprintf('%d.%02d', q$Revision: 1.11 $ =~ /(\d+)/g);
 @ISA         = qw(Exporter);
 @EXPORT      = ();
 @EXPORT_OK   = qw(&lists &users &caps &commify);
-%EXPORT_TAGS = ( all => [ qw(&lists &users &caps &commify) ] );
+%EXPORT_TAGS = ( all => \@EXPORT_OK );
 
 sub users {
 	return _get_data(shift);
@@ -214,7 +214,7 @@ L<http://freshmeat.net/projects/colloquy-talker/>
 
 =head1 VERSION
 
-$Id: Data.pm,v 1.9 2005/12/29 18:16:59 nicolaw Exp $
+$Id: Data.pm,v 1.11 2006/01/07 12:13:27 nicolaw Exp $
 
 =head1 AUTHOR
 
@@ -224,11 +224,11 @@ L<http://perlgirl.org.uk>
 
 =head1 COPYRIGHT
 
-(c) Nicola Worthington 2005. This program is free software; you can
-redistribute it and/or modify it under the GNU GPL.
+Copyright 2005,2006 Nicola Worthington.
 
-See the file COPYING in this distribution, or
-L<http://www.gnu.org/licenses/gpl.txt>
+This software is licensed under The Apache Software License, Version 2.0.
+
+L<http://www.apache.org/licenses/LICENSE-2.0>
 
 =cut
 
